package
Version:
v1.0.2
Opens a new window with list of versions in this module.
Published: Jul 26, 2026
License: MIT
Opens a new window with license information.
Imports: 10
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
Package telegram announces releases to Telegram.
type Config struct {
ConsumerToken string `env:"TELEGRAM_TOKEN,notEmpty"`
}
type SendMessageResponse struct {
Ok bool `json:"ok"`
ErrorCode int `json:"error_code"`
Description string `json:"description"`
}
Source Files
¶
Click to show internal directories.
Click to hide internal directories.